@@ -530,20 +530,13 @@ U64 load_image_from_memory(char *address, unsigned int pages)
  */
 U64 load_image_from_device(char *fs_type, char *device, char *file)
 {
-    long offset;
-    unsigned long count;
-
     int channel;
     int fd;
     int blkno;
 
     char *iobuf;
-    char *to;
-
-    char *cptr;
-
-    int zipped;
 
+    char *where ;
 /*
  * We must read an image from a device
  */
@@ -564,35 +557,24 @@ U64 load_image_from_device(char *fs_type, char *device, char *file)
     printk("...%s\n", fd >= 0 ? "found it" : "failed to find it");
 #endif
 
-    if (fd < 0)
-	return 0;
+    if (fd < 0) 
+	return 0 ;
 
 /*
- *  Is it a zipped image (.gz suffix)?
+ * First, try and load it as if it were a zipped image.
  */
-    zipped = FALSE;
-    cptr = file + strlen(file) - 3;
-    if (strcmp((const char *) cptr, (const char *) ".gz") == 0)
-	zipped = TRUE;
-    else {
-	if (strcmp((const char *) cptr, (const char *) ".GZ") == 0)
-	    zipped = TRUE;
+    where = (char *) kmalloc(MAX_KERNEL_SIZE + 512, 0) + 512 ;
+    if (!where) {
+      printk("ERROR: failed to allocate memory to hold the uncompressed kernel\n") ;
+      return 0 ;
     }
-    if (zipped) {
-	char *where;
-/*
- *  Uncompress it into some temporary memory.
- */
-	where =
-	  (char *) kmalloc(MAX_KERNEL_SIZE + 512, 0) + 512;
 #ifdef DEBUG_MINIBOOT
-	printk("..uncompressing image into 0x%p\n", where);
+    printk("..trying to uncompress image into 0x%p\n", where);
 #endif
-	uncompress_kernel(fd, where);
-	kernel_entry =
-	    load_image_from_memory((char *) where,
-				   _PHYSICAL_TO_PFN(MAX_KERNEL_SIZE));
-    } else {
+    if (uncompress_kernel(fd, where) < 0) {
+      char *ptr ; 
+
+      /* no, it wasn't a compressed kernel, carry on as normal */
 /*
  *  Allocate an iobuf for the transfers and read the first block of the
  *  file into it (the section headers).  Make it 512 bytes aligned.
@@ -602,93 +584,31 @@ U64 load_image_from_device(char *fs_type, char *device, char *file)
 #ifdef DEBUG_MINIBOOT
 	printk("...allocated iobuf at 0x%p\n", iobuf);
 #endif
+	ptr = where ;
 	blkno = 0;			/* logical block number */
-	if (__bread(fd, blkno++, iobuf) < 0) {
-	  printk("MILO: error reading image (block number = 0)\n");
-	  return 0;
+	while (__bread(fd, blkno++, iobuf) == 0) {
+	  printk("#");
+	  memcpy((char *) ptr, iobuf, IOBUF_SIZE);
+	  ptr += IOBUF_SIZE ;
+	  if ((ptr - where) > MAX_KERNEL_SIZE) break ;
 	}
 
-	/* check the kernel header */
-	offset = extract_header_info((char *) iobuf);
-	if (offset < 0) return 0;
-
-	/* How many pages does the kernel take up?  Don't forget to include the
-	 * pages between KERNEL_START and START_ADDR */
-	kernel_pages = (kernel_memsize + PAGE_SIZE - 1) >> PAGE_SHIFT;
-	kernel_pages += ((kernel_entry - KERNEL_START) >> PAGE_SHIFT);
-
-#ifdef DEBUG_MINIBOOT
-	printk("First block loaded; kernel uses %ld page(s)\n", kernel_pages);
-#endif
-
-/*
- *  Copy the kernel bit by bit from the file into memory.
- */
-#ifdef BOOT_VERBOSE
-	printk("...copying %s into memory (block size = 0x%X)", 
-	  file, IOBUF_SIZE);
-	printk(" at physical address 0x%Lx\n", ah->text_start);
-#endif
-#ifdef BOOT_VERBOSE
-	printk("...Text segment offset @0x%x (%d)\n", offset, offset);
-#endif
-/*
- *  We may have the first part of the image in this block.  Check before
- *  we embark on a reading frenzy.
- */
-	count = 0;
-	to = (char *) kernel_at;
-
-	if (offset > IOBUF_SIZE) {
-	    blkno = offset / IOBUF_SIZE;
-	    if (__bread(fd, blkno, to) < 0) {
-	      printk("MILO: error reading image (block number = %d)\n", blkno);
-	      return 0;
-	    }
-	    offset -= blkno * IOBUF_SIZE;
-	}
-
-	/* read the first part of the image from the iobuf */
-	if (offset < IOBUF_SIZE) {
-	    int size;
-
-	    size = IOBUF_SIZE - offset;
-	    memcpy((char *) kernel_at, iobuf + offset, size);
-	    printk("#");
-
-	    count += size;
-	    to += size;
-	}
-
-	/* read the rest of the blocks directly where we want them */
-	while (count < kernel_filesize) {
-	    if (__bread(fd, blkno, to) < 0) {
-	      printk("MILO: error reading image (block number = %d)\n", blkno);
-	      return 0;
-	    }
-#if 1
-	    printk("#");
-#else
-	    printk("%08X\r", to);
-#endif
-	    blkno++ ;
-	    to += IOBUF_SIZE;
-	    count += IOBUF_SIZE;
-	}
-	printk("\n");
-/*
- *  Zero the bss part of the image.
- */
-#ifdef DEBUG_MINIBOOT
-	printk("...clearing bss memory between 0x%p and 0x%p\n", 
-	       (char *) kernel_at + kernel_filesize,
-	       (char *) kernel_at + kernel_memsize);
-#endif
-	memset((char *) kernel_at + kernel_filesize, 0,
-	       kernel_memsize - kernel_filesize);
+	/* free off the iobuf */
+	kfree(iobuf) ;
 
+	/* close the device */
 	__close(channel);
     }
+
+    /* ok, now load the kernel image from wherever we allocated memory */
+    kernel_entry =
+      load_image_from_memory((char *) where,
+			     _PHYSICAL_TO_PFN(MAX_KERNEL_SIZE));
+
+    /* free off the allocated memory */
+    kfree(where) ;
+
+    /* tell the world (maybe) */
 #ifdef BOOT_VERBOSE
     printk("...Image loaded into memory, entry @ 0x%lx\n", kernel_entry);
 #endif
@@ -1065,7 +985,8 @@ void __main(void)
     wrsp(PALCODE_AT - 1024);
     wrfen();
 
-    milo_memory_size = high_memory = (void *)memory_size();
+    milo_memory_size = memory_size();
+    high_memory = (void *)milo_memory_size ;
 #if defined(BOOT_VERBOSE)
     printk("...memory size is 0x%Lx\n", milo_memory_size);
 #endif
