@@ -219,8 +219,8 @@ extern char *floppy_track_buffer;
 #ifdef CONFIG_SCSI
 int (* dispatch_scsi_info_ptr) (int ino, char *buffer, char **start,
 				off_t offset, int length, int inout) = NULL ;
-struct proc_dir_entry scsi_dir[];
-struct proc_dir_entry scsi_hba_dir[];
+struct proc_dir_entry scsi_dir[1];
+struct proc_dir_entry scsi_hba_dir[1];
 #endif
 
 /*
@@ -871,7 +871,7 @@ long block_read(struct inode * inode, struct file * filp, char * buf, unsigned l
 	printk("\tmajor = %d\n", major);
 	return 0;
     } else {
-	int read;
+	unsigned long read;
 	int blocksize, block;
 	struct buffer_head *bh;
 /*
@@ -909,7 +909,7 @@ long block_read(struct inode * inode, struct file * filp, char * buf, unsigned l
 /*
  *  Failed, return just how much we managed to read.
  */
-		printk("block_read: read failed (after %d bytes)\n", read);
+		printk("block_read: read failed (after %lu bytes)\n", read);
 		return read;          
 	    } else {
 		int size;
@@ -1508,7 +1508,7 @@ int brw_page(int rw, struct page *page, kdev_t dev, int b[], int size, int bmap)
 }
 
 /* int register_symtab(struct symbol_table *intab) */
-int register_symtab(void *intab)
+int register_symtab_from(void *intab, int count)
 {
 #ifdef DEBUG_DEVICES
   printk("register_symtab() called\n") ;
@@ -1520,14 +1520,9 @@ void rand_initialize(void) {}
 void rand_initialize_irq(int irq) {}
 void rand_initialize_blkdev(int irq, int mode) {}
 
-int
-register_symtab_from(struct symbol_table *intab, long *from)
-{
-  return 0 ;
-}
-
 int kerneld_send(int msgtype, int ret_size, int msgsz,
 		const char *text, const char *ret_val)
 {
   return -ENOSYS;
 }
+
