@@ -265,14 +265,14 @@ static void boot_cmd(char *fs_type,
 
     /* Uncompress it into some temporary memory. */
     where = 
-      (char *) kmalloc(START_SIZE + 512, 0) + 512;
+      (char *) kmalloc(MAX_KERNEL_SIZE + 512, 0) + 512;
 #ifdef DEBUG_MINIBOOT
     printk("..uncompressing image into 0x%p\n", where);
 #endif
     uncompress_kernel(-1, where);
 
     entry = load_image_from_memory(where, 
-      _PHYSICAL_TO_PFN(START_SIZE));
+      _PHYSICAL_TO_PFN(MAX_KERNEL_SIZE));
 #else
     entry = load_image_from_device(fs_type, devname, filename);
 #endif
@@ -288,7 +288,7 @@ static void boot_cmd(char *fs_type,
     printk("...freeing original marked kernel pages: ");
 #endif
     mark_many_pfn(_PHYSICAL_TO_PFN(KERNEL_START), 
-      _PHYSICAL_TO_PFN(START_SIZE), 
+      _PHYSICAL_TO_PFN(MAX_KERNEL_SIZE), 
       FREE_PAGE);
 #ifdef BOOT_VERBOSE
     printk("...marking real kernel pages as occupied: ");
@@ -998,6 +998,9 @@ static void milo_whatami(void)
 #endif
 #ifdef CONFIG_SCSI_BUSLOGIC
     printk(", Buslogic") ;
+#endif
+#ifdef CONFIG_SCSI_AIC7XXX
+    printk(", AHA2940UW") ;
 #endif
     printk(")") ;
 #endif
